class Config:
    def __init__(self):
        self.compact = True
        self.remote_data_max_retry = 3
        self.bandori_station_token_name = "Tsugu"
        self.bandori_station_token = "ZtV4EX2K9Onb"
        self.disable_gacha_simulate_group_ids = []


config = Config()


